==> haskell-safe-exceptions-0.1.7.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safe-exceptions
version: 0.1.7.0
id: safe-exceptions-0.1.7.0-80UPwAuQu9gD9VIvsIJu2H
key: safe-exceptions-0.1.7.0-80UPwAuQu9gD9VIvsIJu2H
license: MIT
copyright: 2016 FP Complete
maintainer: michael@fpcomplete.com
homepage: https://github.com/fpco/safe-exceptions#readme
synopsis: Safe, consistent, and easy exception handling
description:
    Please see README.md
category: Control
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Control.Exception.Safe
abi: 80e5b79100441c31b0b6bae9b7584f54
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/safe-exceptions-0.1.7.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/safe-exceptions-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/safe-exceptions-0.1.7.0
hs-libraries: HSsafe-exceptions-0.1.7.0-80UPwAuQu9gD9VIvsIJu2H
depends:
    base-4.10.1.0 deepseq-1.4.3.0
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock
haddock-html: /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safe-exceptions-0.1.7.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safe-exceptions
version: 0.1.7.0
id: safe-exceptions-0.1.7.0-LxfC1A9LbB1F78c56l987Z
key: safe-exceptions-0.1.7.0-LxfC1A9LbB1F78c56l987Z
license: MIT
copyright: 2016 FP Complete
maintainer: michael@fpcomplete.com
homepage: https://github.com/fpco/safe-exceptions#readme
synopsis: Safe, consistent, and easy exception handling
description:
    Please see README.md
category: Control
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Control.Exception.Safe
abi: 5aff85dd16404aec1cdf14c6b4dbd074
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/safe-exceptions-0.1.7.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/safe-exceptions-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/safe-exceptions-0.1.7.0
hs-libraries: HSsafe-exceptions-0.1.7.0-LxfC1A9LbB1F78c56l987Z
depends:
    base-4.10.1.0 deepseq-1.4.3.0
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock
haddock-html: /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
